==> ajv-1.4.9.tgz: package/lib/dotjs/minimum.js <==
'use strict';
module.exports = function generate_minimum(it) {
  var out = ' ';
  var $lvl = it.level,
    $dataLvl = it.dataLevel,
    $schema = it.schema['minimum'],
    $schemaPath = it.schemaPath + '.' + 'minimum',
    $breakOnError = !it.opts.allErrors;
  var $data = 'data' + ($dataLvl || ''),
    $valid = 'valid' + $lvl,
    $errs = 'errs' + $lvl;
  var $exclusive = it.schema.exclusiveMinimum === true,
    $op = $exclusive ? '>' : '>=',
    $notOp = $exclusive ? '<=' : '<';
  out += 'if (' + ($data) + ' ' + ($notOp) + ' ' + ($schema) + ') {  ';
  if (!it.compositeRule && $breakOnError) {
    out += ' validate.errors = [ { keyword: \'' + ('minimum') + '\', dataPath: (dataPath || \'\') + ' + (it.errorPath) + ' ';
    if (it.opts.messages !== false) {
      out += ' , message: \'should be ' + ($op) + ' ' + ($schema) + '\' ';
    }
    if (it.opts.verbose || it.opts.i18n) {
      out += ' , schema: ' + ($schema) + ' ';
    }
    if (it.opts.verbose) {
      out += ' , data: ' + ($data) + ' ';
    }
    if (it.opts.i18n) {
      out += ', params: { condition: \'' + ($op) + ' ' + ($schema) + '\' }';
    }
    out += ' }]; return false; ';
  } else {
    out += '  var err =   { keyword: \'' + ('minimum') + '\', dataPath: (dataPath || \'\') + ' + (it.errorPath) + ' ';
    if (it.opts.messages !== false) {
      out += ' , message: \'should be ' + ($op) + ' ' + ($schema) + '\' ';
    }
    if (it.opts.verbose || it.opts.i18n) {
      out += ' , schema: ' + ($schema) + ' ';
    }
    if (it.opts.verbose) {
      out += ' , data: ' + ($data) + ' ';
    }
    if (it.opts.i18n) {
      out += ', params: { condition: \'' + ($op) + ' ' + ($schema) + '\' }';
    }
    out += ' }; if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ';
  }
  out += '} ';
  if ($breakOnError) {
    out += ' else { ';
  }
  return out;
}

==> ajv-2.2.2.tgz: package/lib/dotjs/minimum.js <==
'use strict';
module.exports = function generate_minimum(it) {
  var out = ' ';
  var $lvl = it.level,
    $dataLvl = it.dataLevel,
    $schema = it.schema['minimum'],
    $schemaPath = it.schemaPath + '.' + 'minimum',
    $breakOnError = !it.opts.allErrors;
  var $data = 'data' + ($dataLvl || ''),
    $valid = 'valid' + $lvl,
    $errs = 'errs' + $lvl;
  var $exclusive = it.schema.exclusiveMinimum === true,
    $op = $exclusive ? '>' : '>=',
    $notOp = $exclusive ? '<=' : '<';
  out += 'if (' + ($data) + ' ' + ($notOp) + ' ' + ($schema) + ') {  ';
  if (!it.compositeRule && $breakOnError) {
    out += ' validate.errors = [ { keyword: \'' + ('minimum') + '\' , dataPath: (dataPath || \'\') + ' + (it.errorPath) + ' , schemaPath: "' + ($schemaPath) + '" , params: { comparison: \'' + ($op) + '\', limit: ' + ($schema) + ', exclusive: ' + ($exclusive) + ' } ';
    if (it.opts.messages !== false) {
      out += ' , message: \'should be ' + ($op) + ' ' + ($schema) + '\' ';
    }
    if (it.opts.verbose) {
      out += ' , schema: ' + ($schema) + ' , data: ' + ($data) + ' ';
    }
    out += ' }]; return false; ';
  } else {
    out += '  var err =   { keyword: \'' + ('minimum') + '\' , dataPath: (dataPath || \'\') + ' + (it.errorPath) + ' , schemaPath: "' + ($schemaPath) + '" , params: { comparison: \'' + ($op) + '\', limit: ' + ($schema) + ', exclusive: ' + ($exclusive) + ' } ';
    if (it.opts.messages !== false) {
      out += ' , message: \'should be ' + ($op) + ' ' + ($schema) + '\' ';
    }
    if (it.opts.verbose) {
      out += ' , schema: ' + ($schema) + ' , data: ' + ($data) + ' ';
    }
    out += ' }; if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ';
  }
  out += '} ';
  if ($breakOnError) {
    out += ' else { ';
  }
  return out;
}
